@@ -14,9 +14,9 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.78';    # VERSION
+our $VERSION = '3.79';    # VERSION
 my @OPTIONS_ATTRIBUTES
-    = qw/format short repeatable negativable autosplit doc order/;
+    = qw/format short repeatable negativable autosplit doc order json/;
 
 sub import {
     my ( undef, @import ) = @_;
@@ -127,6 +127,13 @@ sub _validate_and_filter_options {
     $options{doc} = $options{documentation} if !defined $options{doc};
     $options{order} = 0 if !defined $options{order};
 
+    if ( $options{json} ) {
+        delete $options{repeatable};
+        delete $options{autosplit};
+        delete $options{negativable};
+        $options{format} = 's';
+    }
+
     my %cmdline_options = map { ( $_ => $options{$_} ) }
         grep { exists $options{$_} } @OPTIONS_ATTRIBUTES, 'required';
 
@@ -155,7 +162,7 @@ MooX::Options - add option keywords to your object (Mo/Moo/Moose)
 
 =head1 VERSION
 
-version 3.78
+version 3.79
 
 =head1 MooX::Options
 
@@ -464,6 +471,27 @@ Ex :
 
 Specified the order of the attribute.
 
+The order value is an integer.
+
+=item json
+
+The parameter will be treat like a json string.
+
+Ex :
+
+    {
+        package t;
+        use Moo;
+        use MooX::Options;
+
+        option 'hash' => (is => 'ro', json => 1);
+
+        1;
+    }
+    local @ARGV=('--hash', '{"a":1,"b":2}');
+    my $t = t->new_with_options;
+    t->hash # { a => 1, b => 2 }
+
 =head1 namespace::clean
 
 To use namespace::clean you need to add 2 methods as an exception. It is use by MooX::Options when you run the new_with_options methods.
