@@ -12,7 +12,7 @@ package MooX::Options::Role;
 use strict;
 use warnings;
 
-our $VERSION = '3.78';    # VERSION
+our $VERSION = '3.79';    # VERSION
 
 use MRO::Compat;
 use Moo::Role;
@@ -20,6 +20,7 @@ use Getopt::Long 2.38;
 use Getopt::Long::Descriptive 0.091;
 use Regexp::Common;
 use Data::Record;
+use JSON;
 
 requires qw/_options_data _options_config/;
 
@@ -60,11 +61,14 @@ sub parse_options {
     };
 
     my %has_to_split;
-    my @sorted_keys = sort {
-        $options_data{$a}{order} <=> $options_data{$b}{order}  # sort by order
-            or $a cmp $b    # sort by attr name
-    } keys %options_data;
-    for my $name (@sorted_keys) {
+    for my $name (
+        sort {
+            $options_data{$a}{order}
+                <=> $options_data{$b}{order}    # sort by order
+                or $a cmp $b                    # sort by attr name
+        } keys %options_data
+        )
+    {
         my %data = %{ $options_data{$name} };
         my $doc  = $data{doc};
         $doc = "no doc for $name" if !defined $doc;
@@ -125,7 +129,12 @@ sub parse_options {
         {
             my $val = $opt->$name();
             if ( defined $val ) {
-                $cmdline_params{$name} = $val;
+                if ( $data{json} ) {
+                    $cmdline_params{$name} = decode_json($val);
+                }
+                else {
+                    $cmdline_params{$name} = $val;
+                }
             }
         }
         push @missing_required, $name
@@ -163,7 +172,7 @@ MooX::Options::Role - role that is apply to your object
 
 =head1 VERSION
 
-version 3.78
+version 3.79
 
 =head1 METHODS
 
